@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # This file is part of Glances.
 #
@@ -9,16 +8,16 @@
 
 """Manage the Glances client."""
 
-import ujson
-import socket
 import sys
 import time
 
+import ujson
+
 from glances import __version__
 from glances.globals import Fault, ProtocolError, ServerProxy, Transport
 from glances.logger import logger
-from glances.stats_client import GlancesStatsClient
 from glances.outputs.glances_curses import GlancesCursesClient
+from glances.stats_client import GlancesStatsClient
 from glances.timer import Counter
 
 
@@ -29,7 +28,7 @@ class GlancesClientTransport(Transport):
         self.timeout = timeout
 
 
-class GlancesClient(object):
+class GlancesClient:
     """This class creates and manages the TCP client."""
 
     def __init__(self, config=None, args=None, timeout=7, return_to_browser=False):
@@ -48,10 +47,12 @@ class GlancesClient(object):
 
         # Build the URI
         if args.password != "":
-            self.uri = 'http://{}:{}@{}:{}'.format(args.username, args.password, args.client, args.port)
+            self.uri = f'http://{args.username}:{args.password}@{args.client}:{args.port}'
         else:
-            self.uri = 'http://{}:{}'.format(args.client, args.port)
-        logger.debug("Try to connect to {}".format(self.uri))
+            self.uri = f'http://{args.client}:{args.port}'
+
+        # Avoid logging user credentials
+        logger.debug(f"Try to connect to 'http://{args.client}:{args.port}'")
 
         # Try to connect to the URI
         transport = GlancesClientTransport()
@@ -60,7 +61,7 @@ class GlancesClient(object):
         try:
             self.client = ServerProxy(self.uri, transport=transport)
         except Exception as e:
-            self.log_and_exit("Client couldn't create socket {}: {}".format(self.uri, e))
+            self.log_and_exit(f"Client couldn't create socket {self.uri}: {e}")
 
     @property
     def quiet(self):
@@ -93,10 +94,10 @@ class GlancesClient(object):
         client_version = None
         try:
             client_version = self.client.init()
-        except socket.error as err:
+        except OSError as err:
             # Fallback to SNMP
             self.client_mode = 'snmp'
-            logger.error("Connection to Glances server failed ({} {})".format(err.errno, err.strerror))
+            logger.error(f"Connection to Glances server failed ({err.errno} {err.strerror})")
             fall_back_msg = 'No Glances server found. Trying fallback to SNMP...'
             if not self.return_to_browser:
                 print(fall_back_msg)
@@ -104,11 +105,11 @@ class GlancesClient(object):
                 logger.info(fall_back_msg)
         except ProtocolError as err:
             # Other errors
-            msg = "Connection to server {} failed".format(self.uri)
+            msg = f"Connection to server {self.uri} failed"
             if err.errcode == 401:
                 msg += " (Bad username/password)"
             else:
-                msg += " ({} {})".format(err.errcode, err.errmsg)
+                msg += f" ({err.errcode} {err.errmsg})"
             self.log_and_exit(msg)
             return False
 
@@ -118,13 +119,11 @@ class GlancesClient(object):
                 # Init stats
                 self.stats = GlancesStatsClient(config=self.config, args=self.args)
                 self.stats.set_plugins(ujson.loads(self.client.getAllPlugins()))
-                logger.debug("Client version: {} / Server version: {}".format(__version__, client_version))
+                logger.debug(f"Client version: {__version__} / Server version: {client_version}")
             else:
                 self.log_and_exit(
-                    (
-                        'Client and server not compatible: '
-                        'Client version: {} / Server version: {}'.format(__version__, client_version)
-                    )
+                    'Client and server not compatible: '
+                    f'Client version: {__version__} / Server version: {client_version}'
                 )
                 return False
 
@@ -180,12 +179,12 @@ class GlancesClient(object):
         """Update stats from Glances/SNMP server."""
         if self.client_mode == 'glances':
             return self.update_glances()
-        elif self.client_mode == 'snmp':
+        if self.client_mode == 'snmp':
             return self.update_snmp()
-        else:
-            self.end()
-            logger.critical("Unknown server mode: {}".format(self.client_mode))
-            sys.exit(2)
+
+        self.end()
+        logger.critical(f"Unknown server mode: {self.client_mode}")
+        sys.exit(2)
 
     def update_glances(self):
         """Get stats from Glances server.
@@ -197,7 +196,7 @@ class GlancesClient(object):
         # Update the stats
         try:
             server_stats = ujson.loads(self.client.getAll())
-        except socket.error:
+        except OSError:
             # Client cannot get server stats
             return "Disconnected"
         except Fault:
@@ -240,12 +239,12 @@ class GlancesClient(object):
                 # Update the stats
                 counter = Counter()
                 cs_status = self.update()
-                logger.debug('Stats updated duration: {} seconds'.format(counter.get()))
+                logger.debug(f'Stats updated duration: {counter.get()} seconds')
 
                 # Export stats using export modules
                 counter_export = Counter()
                 self.stats.export(self.stats)
-                logger.debug('Stats exported duration: {} seconds'.format(counter_export.get()))
+                logger.debug(f'Stats exported duration: {counter_export.get()} seconds')
 
                 # Patch for issue1326 to avoid < 0 refresh
                 adapted_refresh = self.refresh_time - counter.get()
