@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # This file is part of Glances.
 #
@@ -8,16 +7,15 @@
 #
 
 """Curses interface class."""
-from __future__ import unicode_literals
 
-import sys
 import getpass
+import sys
 
-from glances.globals import MACOS, WINDOWS, nativestr, u, itervalues, enable, disable
-from glances.logger import logger
 from glances.events_list import glances_events
-from glances.processes import glances_processes, sort_processes_key_list
+from glances.globals import MACOS, WINDOWS, disable, enable, itervalues, nativestr, u
+from glances.logger import logger
 from glances.outputs.glances_unicode import unicode_message
+from glances.processes import glances_processes, sort_processes_key_list
 from glances.timer import Timer
 
 # Import curses library for "normal" operating system
@@ -32,7 +30,7 @@ except ImportError:
     sys.exit(1)
 
 
-class _GlancesCurses(object):
+class _GlancesCurses:
     """This class manages the curses display (and key pressed).
 
     Note: It is a private class, use GlancesCursesClient or GlancesCursesBrowser.
@@ -147,15 +145,15 @@ class _GlancesCurses(object):
                 logger.critical("Cannot init the curses library.\n")
                 sys.exit(1)
             else:
-                logger.debug("Curses library initialized with term: {}".format(curses.longname()))
+                logger.debug(f"Curses library initialized with term: {curses.longname()}")
         except Exception as e:
             if args.export:
                 logger.info("Cannot init the curses library, quiet mode on and export.")
                 args.quiet = True
                 return
-            else:
-                logger.critical("Cannot init the curses library ({})".format(e))
-                sys.exit(1)
+
+            logger.critical(f"Cannot init the curses library ({e})")
+            sys.exit(1)
 
         # Load configuration file
         self.load_config(config)
@@ -223,11 +221,11 @@ class _GlancesCurses(object):
         try:
             if hasattr(curses, 'start_color'):
                 curses.start_color()
-                logger.debug('Curses interface compatible with {} colors'.format(curses.COLORS))
+                logger.debug(f'Curses interface compatible with {curses.COLORS} colors')
             if hasattr(curses, 'use_default_colors'):
                 curses.use_default_colors()
         except Exception as e:
-            logger.warning('Error initializing terminal color ({})'.format(e))
+            logger.warning(f'Error initializing terminal color ({e})')
 
         # Init colors
         if self.args.disable_bold:
@@ -287,10 +285,13 @@ class _GlancesCurses(object):
                 self.filter_color = curses.color_pair(9) | A_BOLD
                 self.selected_color = curses.color_pair(10) | A_BOLD
                 # Define separator line style
-                curses.init_color(11, 500, 500, 500)
-                curses.init_pair(11, curses.COLOR_BLACK, -1)
-                self.separator = curses.color_pair(11)
-
+                try:
+                    curses.init_color(11, 500, 500, 500)
+                    curses.init_pair(11, curses.COLOR_BLACK, -1)
+                    self.separator = curses.color_pair(11)
+                except Exception:
+                    # Catch exception in TMUX
+                    pass
         else:
             # The screen is NOT compatible with a colored design
             # switch to B&W text styles
@@ -355,8 +356,7 @@ class _GlancesCurses(object):
 
     def get_key(self, window):
         # TODO: Check issue #163
-        ret = window.getch()
-        return ret
+        return window.getch()
 
     def __catch_key(self, return_to_browser=False):
         # Catch the pressed key
@@ -365,7 +365,7 @@ class _GlancesCurses(object):
             return -1
 
         # Actions (available in the global hotkey dict)...
-        logger.debug("Keypressed (code: {})".format(self.pressedkey))
+        logger.debug(f"Keypressed (code: {self.pressedkey})")
         for hotkey in self._hotkeys:
             if self.pressedkey == ord(hotkey) and 'switch' in self._hotkeys[hotkey]:
                 self._handle_switch(hotkey)
@@ -492,7 +492,7 @@ class _GlancesCurses(object):
         if return_to_browser:
             logger.info("Stop Glances client and return to the browser")
         else:
-            logger.info("Stop Glances (keypressed: {})".format(self.pressedkey))
+            logger.info(f"Stop Glances (keypressed: {self.pressedkey})")
 
     def _handle_refresh(self):
         pass
@@ -713,7 +713,7 @@ class _GlancesCurses(object):
         # Display graph generation popup
         if self.args.generate_graph:
             if 'graph' in stats.getExportsList():
-                self.display_popup('Generate graph in {}'.format(self.args.export_graph_path))
+                self.display_popup(f'Generate graph in {self.args.export_graph_path}')
             else:
                 logger.warning('Graph export module is disable. Run Glances with --export graph to enable it.')
                 self.args.generate_graph = False
@@ -732,7 +732,7 @@ class _GlancesCurses(object):
         :param process
         :return: None
         """
-        logger.debug("Selected process to kill: {}".format(process))
+        logger.debug(f"Selected process to kill: {process}")
 
         if 'childrens' in process:
             pid_to_kill = process['childrens']
@@ -752,9 +752,9 @@ class _GlancesCurses(object):
                 try:
                     ret_kill = glances_processes.kill(pid)
                 except Exception as e:
-                    logger.error('Can not kill process {} ({})'.format(pid, e))
+                    logger.error(f'Can not kill process {pid} ({e})')
                 else:
-                    logger.info('Kill signal has been sent to process {} (return code: {})'.format(pid, ret_kill))
+                    logger.info(f'Kill signal has been sent to process {pid} (return code: {ret_kill})')
 
     def __display_header(self, stat_display):
         """Display the firsts lines (header) in the Curses interface.
@@ -826,7 +826,7 @@ class _GlancesCurses(object):
                     max_width=quicklook_width, args=self.args
                 )
             except AttributeError as e:
-                logger.debug("Quicklook plugin not available (%s)" % e)
+                logger.debug(f"Quicklook plugin not available ({e})")
             else:
                 plugin_widths['quicklook'] = self.get_stats_display_width(stat_display["quicklook"])
                 stats_width = sum(itervalues(plugin_widths)) + 1
@@ -986,7 +986,8 @@ class _GlancesCurses(object):
             popup.refresh()
             self.wait(duration * 1000)
             return True
-        elif popup_type == 'input':
+
+        if popup_type == 'input':
             logger.info(popup_type)
             logger.info(is_password)
             # Create a sub-window for the text field
@@ -1006,17 +1007,17 @@ class _GlancesCurses(object):
                 self.set_cursor(0)
                 if textbox != '':
                     return textbox
-                else:
-                    return None
-            else:
-                textbox = GlancesTextbox(sub_pop, insert_mode=True)
-                textbox.edit()
-                self.set_cursor(0)
-                if textbox.gather() != '':
-                    return textbox.gather()[:-1]
-                else:
-                    return None
-        elif popup_type == 'yesno':
+                return None
+
+            # No password
+            textbox = GlancesTextbox(sub_pop, insert_mode=True)
+            textbox.edit()
+            self.set_cursor(0)
+            if textbox.gather() != '':
+                return textbox.gather()[:-1]
+            return None
+
+        if popup_type == 'yesno':
             # # Create a sub-window for the text field
             sub_pop = popup.derwin(1, 2, len(sentence_list) + 1, len(m) + 2)
             sub_pop.attron(self.colors_list['FILTER'])
@@ -1034,6 +1035,8 @@ class _GlancesCurses(object):
             # self.term_window.keypad(0)
             return textbox.gather()
 
+        return None
+
     def display_plugin(self, plugin_stats, display_optional=True, display_additional=True, max_y=65535, add_space=0):
         """Display the plugin_stats on the screen.
 
@@ -1128,6 +1131,7 @@ class _GlancesCurses(object):
 
         # Have empty lines after the plugins
         self.next_line += add_space
+        return None
 
     def clear(self):
         """Erase the content of the screen.
@@ -1210,8 +1214,7 @@ class _GlancesCurses(object):
             if isexitkey and self.args.help_tag:
                 # Quit from help should return to main screen, not exit #1874
                 self.args.help_tag = not self.args.help_tag
-                isexitkey = False
-                return isexitkey
+                return False
 
             if not isexitkey and pressedkey > -1:
                 # Redraw display
@@ -1252,7 +1255,7 @@ class _GlancesCurses(object):
                     )
                 )
         except Exception as e:
-            logger.debug('ERROR: Can not compute plugin width ({})'.format(e))
+            logger.debug(f'ERROR: Can not compute plugin width ({e})')
             return 0
         else:
             return c
@@ -1265,7 +1268,7 @@ class _GlancesCurses(object):
         try:
             c = [i['msg'] for i in curse_msg['msgdict']].count('\n')
         except Exception as e:
-            logger.debug('ERROR: Can not compute plugin height ({})'.format(e))
+            logger.debug(f'ERROR: Can not compute plugin height ({e})')
             return 0
         else:
             return c + 1
@@ -1279,21 +1282,21 @@ class GlancesCursesClient(_GlancesCurses):
     """Class for the Glances curse client."""
 
 
-class GlancesTextbox(Textbox, object):
+class GlancesTextbox(Textbox):
     def __init__(self, *args, **kwargs):
-        super(GlancesTextbox, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def do_command(self, ch):
         if ch == 10:  # Enter
             return 0
         if ch == 127:  # Back
             return 8
-        return super(GlancesTextbox, self).do_command(ch)
+        return super().do_command(ch)
 
 
-class GlancesTextboxYesNo(Textbox, object):
+class GlancesTextboxYesNo(Textbox):
     def __init__(self, *args, **kwargs):
-        super(GlancesTextboxYesNo, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def do_command(self, ch):
-        return super(GlancesTextboxYesNo, self).do_command(ch)
+        return super().do_command(ch)
