@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # This file is part of Glances.
 #
@@ -127,7 +126,7 @@ class PluginModel(GlancesPluginModel):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(PluginModel, self).__init__(
+        super().__init__(
             args=args, config=config, items_history_list=items_history_list, fields_description=fields_description
         )
 
@@ -164,8 +163,7 @@ class PluginModel(GlancesPluginModel):
         conf_podman_sock = self.get_conf_value('podman_sock')
         if len(conf_podman_sock) == 0:
             return "unix:///run/user/1000/podman/podman.sock"
-        else:
-            return conf_podman_sock[0]
+        return conf_podman_sock[0]
 
     def exit(self):
         """Overwrite the exit method to close threads."""
@@ -174,7 +172,7 @@ class PluginModel(GlancesPluginModel):
         if self.podman_extension:
             self.podman_extension.stop()
         # Call the father class
-        super(PluginModel, self).exit()
+        super().exit()
 
     def get_key(self):
         """Return the key of the list."""
@@ -189,7 +187,7 @@ class PluginModel(GlancesPluginModel):
         try:
             ret = deepcopy(self.stats)
         except KeyError as e:
-            logger.debug("docker plugin - Docker export error {}".format(e))
+            logger.debug(f"docker plugin - Docker export error {e}")
             ret = []
 
         # Remove fields uses to compute rate
@@ -209,8 +207,7 @@ class PluginModel(GlancesPluginModel):
         all_tag = self.get_conf_value('all')
         if len(all_tag) == 0:
             return False
-        else:
-            return all_tag[0].lower() == 'true'
+        return all_tag[0].lower() == 'true'
 
     @GlancesPluginModel._check_decorator
     @GlancesPluginModel._log_result_decorator
@@ -262,7 +259,7 @@ class PluginModel(GlancesPluginModel):
     def update_views(self):
         """Update stats views."""
         # Call the father's method
-        super(PluginModel, self).update_views()
+        super().update_views()
 
         if not self.stats:
             return False
@@ -302,7 +299,7 @@ class PluginModel(GlancesPluginModel):
             show_pod_name = True
         self.views['show_pod_name'] = show_pod_name
         show_engine_name = False
-        if len(set(ct["engine"] for ct in self.stats)) > 1:
+        if len({ct["engine"] for ct in self.stats}) > 1:
             show_engine_name = True
         self.views['show_engine_name'] = show_engine_name
 
@@ -321,9 +318,9 @@ class PluginModel(GlancesPluginModel):
         # Title
         msg = '{}'.format('CONTAINERS')
         ret.append(self.curse_add_line(msg, "TITLE"))
-        msg = ' {}'.format(len(self.stats))
+        msg = f' {len(self.stats)}'
         ret.append(self.curse_add_line(msg))
-        msg = ' sorted by {}'.format(sort_for_human[self.sort_key])
+        msg = f' sorted by {sort_for_human[self.sort_key]}'
         ret.append(self.curse_add_line(msg))
         ret.append(self.curse_new_line())
         # Header
@@ -404,13 +401,13 @@ class PluginModel(GlancesPluginModel):
             unit = 'B'
             try:
                 value = self.auto_unit(int(container['io_rx'])) + unit
-                msg = '{:>7}'.format(value)
+                msg = f'{value:>7}'
             except (KeyError, TypeError):
                 msg = '{:>7}'.format('_')
             ret.append(self.curse_add_line(msg))
             try:
                 value = self.auto_unit(int(container['io_wx'])) + unit
-                msg = ' {:<7}'.format(value)
+                msg = f' {value:<7}'
             except (KeyError, TypeError):
                 msg = ' {:<7}'.format('_')
             ret.append(self.curse_add_line(msg))
@@ -425,13 +422,13 @@ class PluginModel(GlancesPluginModel):
                 unit = 'b'
             try:
                 value = self.auto_unit(int(container['network_rx'] * to_bit)) + unit
-                msg = '{:>7}'.format(value)
+                msg = f'{value:>7}'
             except (KeyError, TypeError):
                 msg = '{:>7}'.format('_')
             ret.append(self.curse_add_line(msg))
             try:
                 value = self.auto_unit(int(container['network_tx'] * to_bit)) + unit
-                msg = ' {:<7}'.format(value)
+                msg = f' {value:<7}'
             except (KeyError, TypeError):
                 msg = ' {:<7}'.format('_')
             ret.append(self.curse_add_line(msg))
@@ -453,12 +450,11 @@ class PluginModel(GlancesPluginModel):
         """Analyse the container status."""
         if status == 'running':
             return 'OK'
-        elif status == 'exited':
+        if status == 'exited':
             return 'WARNING'
-        elif status == 'dead':
+        if status == 'dead':
             return 'CRITICAL'
-        else:
-            return 'CAREFUL'
+        return 'CAREFUL'
 
 
 def sort_docker_stats(stats):
