@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Glances - An eye on your system
 #
@@ -10,31 +9,27 @@
 
 """Glances unitary tests suite."""
 
+import json
 import time
 import unittest
-import sys
-import json
 
-# Check Python version
-if sys.version_info < (3, 8):
-    print('Glances requires at least Python 3.8 to run.')
-    sys.exit(1)
-
-from glances.main import GlancesMain
-from glances.stats import GlancesStats
 from glances import __version__
-from glances.globals import WINDOWS, LINUX, subsample, string_value_to_float
+from glances.events_list import GlancesEventsList
+from glances.filter import GlancesFilter, GlancesFilterList
+from glances.globals import LINUX, WINDOWS, string_value_to_float, subsample
+from glances.main import GlancesMain
 from glances.outputs.glances_bars import Bar
-from glances.thresholds import GlancesThresholdOk
-from glances.thresholds import GlancesThresholdCareful
-from glances.thresholds import GlancesThresholdWarning
-from glances.thresholds import GlancesThresholdCritical
-from glances.thresholds import GlancesThresholds
 from glances.plugins.plugin.model import GlancesPluginModel
 from glances.programs import processes_to_programs
 from glances.secure import secure_popen
-from glances.events_list import GlancesEventsList
-from glances.filter import GlancesFilterList, GlancesFilter
+from glances.stats import GlancesStats
+from glances.thresholds import (
+    GlancesThresholdCareful,
+    GlancesThresholdCritical,
+    GlancesThresholdOk,
+    GlancesThresholds,
+    GlancesThresholdWarning,
+)
 
 # Global variables
 # =================
@@ -45,12 +40,11 @@ test_config = core.get_config()
 test_args = core.get_args()
 
 # Init Glances stats
-stats = GlancesStats(config=test_config,
-                     args=test_args)
+stats = GlancesStats(config=test_config, args=test_args)
 
 # Unitest class
 # ==============
-print('Unitary tests for Glances %s' % __version__)
+print(f'Unitary tests for Glances {__version__}')
 
 
 class TestGlances(unittest.TestCase):
@@ -78,7 +72,12 @@ class TestGlances(unittest.TestCase):
         self.assertIsInstance(plugin_instance.get_raw(), (dict, list))
         if plugin_instance.history_enable() and isinstance(plugin_instance.get_raw(), dict):
             self.assertEqual(plugin_instance.get_key(), None)
-            self.assertTrue(all([f in [h['name'] for h in plugin_instance.items_history_list] for f in plugin_instance.get_raw_history()]))
+            self.assertTrue(
+                all(
+                    f in [h['name'] for h in plugin_instance.items_history_list]
+                    for f in plugin_instance.get_raw_history()
+                )
+            )
         elif plugin_instance.history_enable() and isinstance(plugin_instance.get_raw(), list):
             self.assertNotEqual(plugin_instance.get_key(), None)
 
@@ -135,11 +134,17 @@ class TestGlances(unittest.TestCase):
             if isinstance(plugin_instance.get_raw(), dict):
                 first_history_field = plugin_instance.get_items_history_list()[0]['name']
             elif isinstance(plugin_instance.get_raw(), list):
-                first_history_field = '_'.join([plugin_instance.get_raw()[0][plugin_instance.get_key()],
-                                                plugin_instance.get_items_history_list()[0]['name']])
+                first_history_field = '_'.join(
+                    [
+                        plugin_instance.get_raw()[0][plugin_instance.get_key()],
+                        plugin_instance.get_items_history_list()[0]['name'],
+                    ]
+                )
             self.assertEqual(len(plugin_instance.get_raw_history(first_history_field)), 2)
-            self.assertGreater(plugin_instance.get_raw_history(first_history_field)[1][0],
-                               plugin_instance.get_raw_history(first_history_field)[0][0])
+            self.assertGreater(
+                plugin_instance.get_raw_history(first_history_field)[1][0],
+                plugin_instance.get_raw_history(first_history_field)[0][0],
+            )
 
             # Update stats (add third element)
             plugin_instance.update()
@@ -158,10 +163,8 @@ class TestGlances(unittest.TestCase):
         elif isinstance(plugin_instance.get_raw(), list):
             first_history_field = plugin_instance.get_items_history_list()[0]['name']
             first_item = plugin_instance.get_raw()[0][plugin_instance.get_key()]
-            self.assertIsInstance(plugin_instance.get_views(item=first_item,
-                                                            key=first_history_field), dict)
-            self.assertTrue('decoration' in plugin_instance.get_views(item=first_item,
-                                                                      key=first_history_field))
+            self.assertIsInstance(plugin_instance.get_views(item=first_item, key=first_history_field), dict)
+            self.assertTrue('decoration' in plugin_instance.get_views(item=first_item, key=first_history_field))
         self.assertIsInstance(json.loads(plugin_instance.get_json_views()), dict)
         self.assertEqual(json.loads(plugin_instance.get_json_views()), plugin_instance.get_views())
 
@@ -174,13 +177,13 @@ class TestGlances(unittest.TestCase):
         try:
             stats.update()
         except Exception as e:
-            print('ERROR: Stats update failed: %s' % e)
+            print(f'ERROR: Stats update failed: {e}')
             self.assertTrue(False)
         time.sleep(1)
         try:
             stats.update()
         except Exception as e:
-            print('ERROR: Stats update failed: %s' % e)
+            print(f'ERROR: Stats update failed: {e}')
             self.assertTrue(False)
 
         self.assertTrue(True)
@@ -188,7 +191,7 @@ class TestGlances(unittest.TestCase):
     def test_001_plugins(self):
         """Check mandatory plugins."""
         plugins_to_check = ['system', 'cpu', 'load', 'mem', 'memswap', 'network', 'diskio', 'fs']
-        print('INFO: [TEST_001] Check the mandatory plugins list: %s' % ', '.join(plugins_to_check))
+        print('INFO: [TEST_001] Check the mandatory plugins list: {}'.format(', '.join(plugins_to_check)))
         plugins_list = stats.getPluginsList()
         for plugin in plugins_to_check:
             self.assertTrue(plugin in plugins_list)
@@ -196,38 +199,38 @@ class TestGlances(unittest.TestCase):
     def test_002_system(self):
         """Check SYSTEM plugin."""
         stats_to_check = ['hostname', 'os_name']
-        print('INFO: [TEST_002] Check SYSTEM stats: %s' % ', '.join(stats_to_check))
+        print('INFO: [TEST_002] Check SYSTEM stats: {}'.format(', '.join(stats_to_check)))
         stats_grab = stats.get_plugin('system').get_raw()
         for stat in stats_to_check:
             # Check that the key exist
-            self.assertTrue(stat in stats_grab, msg='Cannot find key: %s' % stat)
-        print('INFO: SYSTEM stats: %s' % stats_grab)
+            self.assertTrue(stat in stats_grab, msg=f'Cannot find key: {stat}')
+        print(f'INFO: SYSTEM stats: {stats_grab}')
 
     def test_003_cpu(self):
         """Check CPU plugin."""
         stats_to_check = ['system', 'user', 'idle']
-        print('INFO: [TEST_003] Check mandatory CPU stats: %s' % ', '.join(stats_to_check))
+        print('INFO: [TEST_003] Check mandatory CPU stats: {}'.format(', '.join(stats_to_check)))
         stats_grab = stats.get_plugin('cpu').get_raw()
         for stat in stats_to_check:
             # Check that the key exist
-            self.assertTrue(stat in stats_grab, msg='Cannot find key: %s' % stat)
+            self.assertTrue(stat in stats_grab, msg=f'Cannot find key: {stat}')
             # Check that % is > 0 and < 100
             self.assertGreaterEqual(stats_grab[stat], 0)
             self.assertLessEqual(stats_grab[stat], 100)
-        print('INFO: CPU stats: %s' % stats_grab)
+        print(f'INFO: CPU stats: {stats_grab}')
 
     @unittest.skipIf(WINDOWS, "Load average not available on Windows")
     def test_004_load(self):
         """Check LOAD plugin."""
         stats_to_check = ['cpucore', 'min1', 'min5', 'min15']
-        print('INFO: [TEST_004] Check LOAD stats: %s' % ', '.join(stats_to_check))
+        print('INFO: [TEST_004] Check LOAD stats: {}'.format(', '.join(stats_to_check)))
         stats_grab = stats.get_plugin('load').get_raw()
         for stat in stats_to_check:
             # Check that the key exist
-            self.assertTrue(stat in stats_grab, msg='Cannot find key: %s' % stat)
+            self.assertTrue(stat in stats_grab, msg=f'Cannot find key: {stat}')
             # Check that % is > 0
             self.assertGreaterEqual(stats_grab[stat], 0)
-        print('INFO: LOAD stats: %s' % stats_grab)
+        print(f'INFO: LOAD stats: {stats_grab}')
 
     def test_005_mem(self):
         """Check MEM plugin."""
@@ -237,36 +240,36 @@ class TestGlances(unittest.TestCase):
         stats_grab = stats.get_plugin('mem').get_raw()
         for stat in stats_to_check:
             # Check that the key exist
-            self.assertTrue(stat in stats_grab, msg='Cannot find key: %s' % stat)
+            self.assertTrue(stat in stats_grab, msg=f'Cannot find key: {stat}')
             # Check that % is > 0
             self.assertGreaterEqual(stats_grab[stat], 0)
-        print('INFO: MEM stats: %s' % stats_grab)
+        print(f'INFO: MEM stats: {stats_grab}')
 
     def test_006_memswap(self):
         """Check MEMSWAP plugin."""
         stats_to_check = ['used', 'free', 'total']
-        print('INFO: [TEST_006] Check MEMSWAP stats: %s' % ', '.join(stats_to_check))
+        print('INFO: [TEST_006] Check MEMSWAP stats: {}'.format(', '.join(stats_to_check)))
         stats_grab = stats.get_plugin('memswap').get_raw()
         for stat in stats_to_check:
             # Check that the key exist
-            self.assertTrue(stat in stats_grab, msg='Cannot find key: %s' % stat)
+            self.assertTrue(stat in stats_grab, msg=f'Cannot find key: {stat}')
             # Check that % is > 0
             self.assertGreaterEqual(stats_grab[stat], 0)
-        print('INFO: MEMSWAP stats: %s' % stats_grab)
+        print(f'INFO: MEMSWAP stats: {stats_grab}')
 
     def test_007_network(self):
         """Check NETWORK plugin."""
         print('INFO: [TEST_007] Check NETWORK stats')
         stats_grab = stats.get_plugin('network').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='Network stats is not a list')
-        print('INFO: NETWORK stats: %s' % stats_grab)
+        print(f'INFO: NETWORK stats: {stats_grab}')
 
     def test_008_diskio(self):
         """Check DISKIO plugin."""
         print('INFO: [TEST_008] Check DISKIO stats')
         stats_grab = stats.get_plugin('diskio').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='DiskIO stats is not a list')
-        print('INFO: diskio stats: %s' % stats_grab)
+        print(f'INFO: diskio stats: {stats_grab}')
 
     def test_009_fs(self):
         """Check File System plugin."""
@@ -274,7 +277,7 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_009] Check FS stats')
         stats_grab = stats.get_plugin('fs').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='FileSystem stats is not a list')
-        print('INFO: FS stats: %s' % stats_grab)
+        print(f'INFO: FS stats: {stats_grab}')
 
     def test_010_processes(self):
         """Check Process plugin."""
@@ -283,10 +286,10 @@ class TestGlances(unittest.TestCase):
         stats_grab = stats.get_plugin('processcount').get_raw()
         # total = stats_grab['total']
         self.assertTrue(isinstance(stats_grab, dict), msg='Process count stats is not a dict')
-        print('INFO: PROCESS count stats: %s' % stats_grab)
+        print(f'INFO: PROCESS count stats: {stats_grab}')
         stats_grab = stats.get_plugin('processlist').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='Process count stats is not a list')
-        print('INFO: PROCESS list stats: %s items in the list' % len(stats_grab))
+        print(f'INFO: PROCESS list stats: {len(stats_grab)} items in the list')
         # Check if number of processes in the list equal counter
         # self.assertEqual(total, len(stats_grab))
 
@@ -296,14 +299,14 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_011] Check FOLDER stats')
         stats_grab = stats.get_plugin('folders').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='Folders stats is not a list')
-        print('INFO: Folders stats: %s' % stats_grab)
+        print(f'INFO: Folders stats: {stats_grab}')
 
     def test_012_ip(self):
         """Check IP plugin."""
         print('INFO: [TEST_012] Check IP stats')
         stats_grab = stats.get_plugin('ip').get_raw()
         self.assertTrue(isinstance(stats_grab, dict), msg='IP stats is not a dict')
-        print('INFO: IP stats: %s' % stats_grab)
+        print(f'INFO: IP stats: {stats_grab}')
 
     @unittest.skipIf(not LINUX, "IRQs available only on Linux")
     def test_013_irq(self):
@@ -311,7 +314,7 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_013] Check IRQ stats')
         stats_grab = stats.get_plugin('irq').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='IRQ stats is not a list')
-        print('INFO: IRQ stats: %s' % stats_grab)
+        print(f'INFO: IRQ stats: {stats_grab}')
 
     @unittest.skipIf(not LINUX, "GPU available only on Linux")
     def test_014_gpu(self):
@@ -319,7 +322,7 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_014] Check GPU stats')
         stats_grab = stats.get_plugin('gpu').get_raw()
         self.assertTrue(isinstance(stats_grab, list), msg='GPU stats is not a list')
-        print('INFO: GPU stats: %s' % stats_grab)
+        print(f'INFO: GPU stats: {stats_grab}')
 
     def test_015_sorted_stats(self):
         """Check sorted stats method."""
@@ -352,12 +355,14 @@ class TestGlances(unittest.TestCase):
     def test_016_subsample(self):
         """Test subsampling function."""
         print('INFO: [TEST_016] Subsampling')
-        for l_test in [([1, 2, 3], 4),
-                       ([1, 2, 3, 4], 4),
-                       ([1, 2, 3, 4, 5, 6, 7], 4),
-                       ([1, 2, 3, 4, 5, 6, 7, 8], 4),
-                       (list(range(1, 800)), 4),
-                       (list(range(1, 8000)), 800)]:
+        for l_test in [
+            ([1, 2, 3], 4),
+            ([1, 2, 3, 4], 4),
+            ([1, 2, 3, 4, 5, 6, 7], 4),
+            ([1, 2, 3, 4, 5, 6, 7, 8], 4),
+            (list(range(1, 800)), 4),
+            (list(range(1, 8000)), 800),
+        ]:
             l_subsample = subsample(l_test[0], l_test[1])
             self.assertLessEqual(len(l_subsample), l_test[1])
 
@@ -370,7 +375,7 @@ class TestGlances(unittest.TestCase):
             return
 
         stat = 'DeviceName'
-        print('INFO: [TEST_017] Check SMART stats: {}'.format(stat))
+        print(f'INFO: [TEST_017] Check SMART stats: {stat}')
         stats_grab = stats.get_plugin('smart').get_raw()
         if not is_admin():
             print("INFO: Not admin, SMART list should be empty")
@@ -380,9 +385,9 @@ class TestGlances(unittest.TestCase):
             assert len(stats_grab) == 0
         else:
             print(stats_grab)
-            self.assertTrue(stat in stats_grab[0].keys(), msg='Cannot find key: %s' % stat)
+            self.assertTrue(stat in stats_grab[0].keys(), msg=f'Cannot find key: {stat}')
 
-        print('INFO: SMART stats: %s' % stats_grab)
+        print(f'INFO: SMART stats: {stats_grab}')
 
     def test_017_programs(self):
         """Check Programs function (it's not a plugin)."""
@@ -501,8 +506,7 @@ class TestGlances(unittest.TestCase):
         plugins_list = stats.getPluginsList()
         for plugin in plugins_list:
             for method in mandatories_methods:
-                self.assertTrue(hasattr(stats.get_plugin(plugin), method),
-                                msg='{} has no method {}()'.format(plugin, method))
+                self.assertTrue(hasattr(stats.get_plugin(plugin), method), msg=f'{plugin} has no method {method}()')
 
     def test_096_views(self):
         """Test get_views method"""
@@ -511,14 +515,14 @@ class TestGlances(unittest.TestCase):
         for plugin in plugins_list:
             stats.get_plugin(plugin).get_raw()
             views_grab = stats.get_plugin(plugin).get_views()
-            self.assertTrue(isinstance(views_grab, dict),
-                            msg='{} view is not a dict'.format(plugin))
+            self.assertTrue(isinstance(views_grab, dict), msg=f'{plugin} view is not a dict')
 
     def test_097_attribute(self):
         """Test GlancesAttribute classes"""
         print('INFO: [TEST_097] Test attribute')
         # GlancesAttribute
         from glances.attribute import GlancesAttribute
+
         a = GlancesAttribute('a', description='ad', history_max_size=3)
         self.assertEqual(a.name, 'a')
         self.assertEqual(a.description, 'ad')
@@ -542,6 +546,7 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_098] Test history')
         # GlancesHistory
         from glances.history import GlancesHistory
+
         h = GlancesHistory()
         h.add('a', 1, history_max_size=100)
         h.add('a', 2, history_max_size=100)
@@ -633,10 +638,8 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_700] Secure functions')
 
         if WINDOWS:
-            self.assertIn(secure_popen('echo TEST'), ['TEST\n',
-                                                      'TEST\r\n'])
-            self.assertIn(secure_popen('echo TEST1 && echo TEST2'), ['TEST1\nTEST2\n',
-                                                                     'TEST1\r\nTEST2\r\n'])
+            self.assertIn(secure_popen('echo TEST'), ['TEST\n', 'TEST\r\n'])
+            self.assertIn(secure_popen('echo TEST1 && echo TEST2'), ['TEST1\nTEST2\n', 'TEST1\r\nTEST2\r\n'])
         else:
             self.assertEqual(secure_popen('echo -n TEST'), 'TEST')
             self.assertEqual(secure_popen('echo -n TEST1 && echo -n TEST2'), 'TEST1TEST2')
@@ -647,6 +650,7 @@ class TestGlances(unittest.TestCase):
     def test_800_memory_leak(self):
         """Memory leak check"""
         import tracemalloc
+
         print('INFO: [TEST_800] Memory leak check')
         tracemalloc.start()
         # 3 iterations just to init the stats and fill the memory
@@ -660,7 +664,7 @@ class TestGlances(unittest.TestCase):
         snapshot_end = tracemalloc.take_snapshot()
         snapshot_diff = snapshot_end.compare_to(snapshot_begin, 'filename')
         memory_leak = sum([s.size_diff for s in snapshot_diff])
-        print('INFO: Memory leak: {} bytes'.format(memory_leak))
+        print(f'INFO: Memory leak: {memory_leak} bytes')
 
         # snapshot_begin = tracemalloc.take_snapshot()
         for _ in range(30):
@@ -668,7 +672,7 @@ class TestGlances(unittest.TestCase):
         snapshot_end = tracemalloc.take_snapshot()
         snapshot_diff = snapshot_end.compare_to(snapshot_begin, 'filename')
         memory_leak = sum([s.size_diff for s in snapshot_diff])
-        print('INFO: Memory leak: {} bytes'.format(memory_leak))
+        print(f'INFO: Memory leak: {memory_leak} bytes')
 
         # snapshot_begin = tracemalloc.take_snapshot()
         for _ in range(300):
@@ -676,7 +680,7 @@ class TestGlances(unittest.TestCase):
         snapshot_end = tracemalloc.take_snapshot()
         snapshot_diff = snapshot_end.compare_to(snapshot_begin, 'filename')
         memory_leak = sum([s.size_diff for s in snapshot_diff])
-        print('INFO: Memory leak: {} bytes'.format(memory_leak))
+        print(f'INFO: Memory leak: {memory_leak} bytes')
         snapshot_top = snapshot_end.compare_to(snapshot_begin, 'traceback')
         print("Memory consumption (top 5):")
         for stat in snapshot_top[:5]:
